<?php

namespace Litecms\Happy\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Happy\Models\Happy;

class HappyPolicy
{

    /**
     * Determine if the given user can view the happy.
     *
     * @param UserPolicy $user
     * @param Happy $happy
     *
     * @return bool
     */
    public function view(UserPolicy $user, Happy $happy)
    {
        if ($user->canDo('happy.happy.view') && $user->isAdmin()) {
            return true;
        }

        return $happy->user_id == user_id() && $happy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a happy.
     *
     * @param UserPolicy $user
     * @param Happy $happy
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('happy.happy.create');
    }

    /**
     * Determine if the given user can update the given happy.
     *
     * @param UserPolicy $user
     * @param Happy $happy
     *
     * @return bool
     */
    public function update(UserPolicy $user, Happy $happy)
    {
        if ($user->canDo('happy.happy.edit') && $user->isAdmin()) {
            return true;
        }

        return $happy->user_id == user_id() && $happy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given happy.
     *
     * @param UserPolicy $user
     * @param Happy $happy
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Happy $happy)
    {
        return $happy->user_id == user_id() && $happy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given happy.
     *
     * @param UserPolicy $user
     * @param Happy $happy
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Happy $happy)
    {
        if ($user->canDo('happy.happy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given happy.
     *
     * @param UserPolicy $user
     * @param Happy $happy
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Happy $happy)
    {
        if ($user->canDo('happy.happy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
